@@ -5,11 +5,14 @@ from atlas.config.loader import load_config
 from atlas.config.loader import parse_config
 from atlas.config.models import AdapterConfig
 from atlas.config.models import AdapterType
+from atlas.config.models import AdaptiveProbeConfig
+from atlas.config.models import AdaptiveTeachingConfig
 from atlas.config.models import AtlasConfig
 from atlas.config.models import LLMParameters
 from atlas.config.models import LLMProvider
 from atlas.config.models import OrchestrationConfig
 from atlas.config.models import RIMConfig
+from atlas.config.models import RewardObjectiveConfig
 from atlas.config.models import StorageConfig
 from atlas.config.models import StudentConfig
 from atlas.config.models import TeacherConfig
@@ -18,12 +21,15 @@ from atlas.config.models import ToolDefinition
 __all__ = [
     "AdapterConfig",
     "AdapterType",
+    "AdaptiveProbeConfig",
+    "AdaptiveTeachingConfig",
     "AtlasConfig",
     "ConfigLoadError",
     "LLMParameters",
     "LLMProvider",
     "OrchestrationConfig",
     "RIMConfig",
+    "RewardObjectiveConfig",
     "StorageConfig",
     "StudentConfig",
     "TeacherConfig",
